@@ -14,15 +14,15 @@ use strictures 2;
 use version;
 use Role::Commons -all;
 
-use namespace::clean;
+use namespace::autoclean 0.16;
 
 =head1 VERSION
 
-Version v1.1.6
+Version v1.1.9
 
 =cut
 
-our $VERSION = version->declare("v1.1.6");
+our $VERSION = version->declare("v1.1.9");
 
 =head1 DESCRIPTION
 
