@@ -20,15 +20,15 @@ extends 'Boxer::Part';
 use Types::Standard qw(Str Maybe ArrayRef HashRef);
 use Types::TypeTiny qw(StringLike);
 
-use namespace::clean;
+use namespace::autoclean 0.16;
 
 =head1 VERSION
 
-Version v1.1.6
+Version v1.1.9
 
 =cut
 
-our $VERSION = version->declare("v1.1.6");
+our $VERSION = version->declare("v1.1.9");
 
 =head1 DESCRIPTION
 
@@ -64,22 +64,22 @@ has pkg => (
 	isa => ArrayRef [Str],
 );
 
-has pkg_auto => (
+has 'pkg-auto' => (
 	is  => 'ro',
 	isa => ArrayRef [Str],
 );
 
-has pkg_avoid => (
+has 'pkg-avoid' => (
 	is  => 'ro',
 	isa => ArrayRef [Str],
 );
 
-has pkg_nonfree => (
+has 'pkg-nonfree' => (
 	is  => 'ro',
 	isa => ArrayRef [Str],
 );
 
-has pkg_nonfree_auto => (
+has 'pkg-nonfree-auto' => (
 	is  => 'ro',
 	isa => ArrayRef [Str],
 );
